==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/CustomeraddressRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Customeraddress;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class CustomeraddressRequest extends EntityRequest<Customeraddress> {

    public CustomeraddressRequest(ContextPath contextPath, Optional<Object> value) {
        super(Customeraddress.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public BulkdeletefailureCollectionRequest customerAddress_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("CustomerAddress_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest customerAddress_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("CustomerAddress_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public TransactioncurrencyRequest transactioncurrencyid() {
        return new TransactioncurrencyRequest(contextPath.addSegment("transactioncurrencyid"), Optional.empty());
    }

    public ProcesssessionCollectionRequest customerAddress_ProcessSessions() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("CustomerAddress_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest customerAddress_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("CustomerAddress_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public AccountRequest parentid_account() {
        return new AccountRequest(contextPath.addSegment("parentid_account"), Optional.empty());
    }

    public ContactRequest parentid_contact() {
        return new ContactRequest(contextPath.addSegment("parentid_contact"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SyncerrorCollectionRequest customerAddress_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("CustomerAddress_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest customerAddress_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("CustomerAddress_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest customeraddress_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("customeraddress_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest customeraddress_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("customeraddress_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest customerAddress_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("CustomerAddress_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest customerAddress_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("CustomerAddress_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.53-sources.jar: microsoft/dynamics/crm/entity/request/CustomeraddressRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Customeraddress;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class CustomeraddressRequest extends EntityRequest<Customeraddress> {

    public CustomeraddressRequest(ContextPath contextPath, Optional<Object> value) {
        super(Customeraddress.class, contextPath, value);
    }

    public BulkdeletefailureCollectionRequest customerAddress_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("CustomerAddress_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest customerAddress_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("CustomerAddress_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public TransactioncurrencyRequest transactioncurrencyid() {
        return new TransactioncurrencyRequest(contextPath.addSegment("transactioncurrencyid"), Optional.empty());
    }

    public ProcesssessionCollectionRequest customerAddress_ProcessSessions() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("CustomerAddress_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest customerAddress_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("CustomerAddress_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public AccountRequest parentid_account() {
        return new AccountRequest(contextPath.addSegment("parentid_account"), Optional.empty());
    }

    public ContactRequest parentid_contact() {
        return new ContactRequest(contextPath.addSegment("parentid_contact"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SyncerrorCollectionRequest customerAddress_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("CustomerAddress_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest customerAddress_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("CustomerAddress_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest customeraddress_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("customeraddress_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest customeraddress_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("customeraddress_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest customerAddress_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("CustomerAddress_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest customerAddress_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("CustomerAddress_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

}
